@@ -9,17 +9,20 @@ use solana_program::{
     rent::Rent,
     sysvar::Sysvar,
 };
+use spl_governance_tools::account::create_and_serialize_account_signed;
 
 use crate::{
     error::GovernanceError,
     state::{
         enums::{GovernanceAccountType, InstructionExecutionFlags, ProposalState},
         governance::get_governance_data_for_realm,
-        proposal::{get_proposal_address_seeds, Proposal},
+        proposal::{
+            assert_valid_proposal_options, get_proposal_address_seeds, OptionVoteResult,
+            ProposalOption, ProposalV2, VoteType,
+        },
         realm::get_realm_data_for_governing_token_mint,
         token_owner_record::get_token_owner_record_data_for_realm,
     },
-    tools::account::create_and_serialize_account_signed,
 };
 
 /// Processes CreateProposal instruction
@@ -28,7 +31,9 @@ pub fn process_create_proposal(
     accounts: &[AccountInfo],
     name: String,
     description_link: String,
-    governing_token_mint: Pubkey,
+    vote_type: VoteType,
+    options: Vec<String>,
+    use_deny_option: bool,
 ) -> ProgramResult {
     let account_info_iter = &mut accounts.iter();
 
@@ -37,23 +42,27 @@ pub fn process_create_proposal(
     let governance_info = next_account_info(account_info_iter)?; // 2
 
     let proposal_owner_record_info = next_account_info(account_info_iter)?; // 3
-    let governance_authority_info = next_account_info(account_info_iter)?; // 4
+    let governing_token_mint_info = next_account_info(account_info_iter)?; // 4
+    let governance_authority_info = next_account_info(account_info_iter)?; // 5
 
-    let payer_info = next_account_info(account_info_iter)?; // 5
-    let system_info = next_account_info(account_info_iter)?; // 6
+    let payer_info = next_account_info(account_info_iter)?; // 6
+    let system_info = next_account_info(account_info_iter)?; // 7
 
-    let rent_sysvar_info = next_account_info(account_info_iter)?; // 7
+    let rent_sysvar_info = next_account_info(account_info_iter)?; // 8
     let rent = &Rent::from_account_info(rent_sysvar_info)?;
 
-    let clock_info = next_account_info(account_info_iter)?; // 8
+    let clock_info = next_account_info(account_info_iter)?; // 9
     let clock = Clock::from_account_info(clock_info)?;
 
     if !proposal_info.data_is_empty() {
         return Err(GovernanceError::ProposalAlreadyExists.into());
     }
 
-    let realm_data =
-        get_realm_data_for_governing_token_mint(program_id, realm_info, &governing_token_mint)?;
+    let realm_data = get_realm_data_for_governing_token_mint(
+        program_id,
+        realm_info,
+        governing_token_mint_info.key,
+    )?;
 
     let mut governance_data =
         get_governance_data_for_realm(program_id, governance_info, realm_info.key)?;
@@ -88,10 +97,26 @@ pub fn process_create_proposal(
         .unwrap();
     proposal_owner_record_data.serialize(&mut *proposal_owner_record_info.data.borrow_mut())?;
 
-    let proposal_data = Proposal {
-        account_type: GovernanceAccountType::Proposal,
+    assert_valid_proposal_options(&options, &vote_type)?;
+
+    let proposal_options: Vec<ProposalOption> = options
+        .iter()
+        .map(|o| ProposalOption {
+            label: o.to_string(),
+            vote_weight: 0,
+            vote_result: OptionVoteResult::None,
+            instructions_executed_count: 0,
+            instructions_count: 0,
+            instructions_next_index: 0,
+        })
+        .collect();
+
+    let deny_vote_weight = if use_deny_option { Some(0) } else { None };
+
+    let proposal_data = ProposalV2 {
+        account_type: GovernanceAccountType::ProposalV2,
         governance: *governance_info.key,
-        governing_token_mint,
+        governing_token_mint: *governing_token_mint_info.key,
         state: ProposalState::Draft,
         token_owner_record: *proposal_owner_record_info.key,
 
@@ -109,25 +134,23 @@ pub fn process_create_proposal(
         executing_at: None,
         closed_at: None,
 
-        instructions_executed_count: 0,
-        instructions_count: 0,
-        instructions_next_index: 0,
-
         execution_flags: InstructionExecutionFlags::None,
 
-        yes_votes_count: 0,
-        no_votes_count: 0,
+        vote_type,
+        options: proposal_options,
+        deny_vote_weight,
+
         max_vote_weight: None,
         vote_threshold_percentage: None,
     };
 
-    create_and_serialize_account_signed::<Proposal>(
+    create_and_serialize_account_signed::<ProposalV2>(
         payer_info,
         proposal_info,
         &proposal_data,
         &get_proposal_address_seeds(
             governance_info.key,
-            &governing_token_mint,
+            governing_token_mint_info.key,
             &governance_data.proposals_count.to_le_bytes(),
         ),
         program_id,
