@@ -7,6 +7,7 @@ use solana_program::{
     rent::Rent,
     sysvar::Sysvar,
 };
+use spl_governance_tools::account::create_and_serialize_account_signed;
 
 use crate::{
     error::GovernanceError,
@@ -18,9 +19,7 @@ use crate::{
         },
         realm_config::{get_realm_config_address_seeds, RealmConfigAccount},
     },
-    tools::{
-        account::create_and_serialize_account_signed, spl_token::create_spl_token_account_signed,
-    },
+    tools::spl_token::create_spl_token_account_signed,
 };
 
 /// Processes CreateRealm instruction
@@ -92,9 +91,9 @@ pub fn process_create_realm(
             account_type: GovernanceAccountType::RealmConfig,
             realm: *realm_info.key,
             community_voter_weight_addin: Some(*community_voter_weight_addin_info.key),
-            reserved_1: None,
-            reserved_2: None,
-            reserved_3: None,
+            community_max_vote_weight_addin: None,
+            council_voter_weight_addin: None,
+            council_max_vote_weight_addin: None,
             reserved: [0; 128],
         };
 
