@@ -2,7 +2,6 @@
 
 use std::cmp::Ordering;
 
-use borsh::BorshSerialize;
 use solana_program::{
     account_info::{next_account_info, AccountInfo},
     entrypoint::ProgramResult,
@@ -10,6 +9,7 @@ use solana_program::{
     rent::Rent,
     sysvar::Sysvar,
 };
+use spl_governance_tools::account::create_and_serialize_account_signed;
 
 use crate::{
     error::GovernanceError,
@@ -18,17 +18,17 @@ use crate::{
         governance::get_governance_data,
         proposal::get_proposal_data_for_governance,
         proposal_instruction::{
-            get_proposal_instruction_address_seeds, InstructionData, ProposalInstruction,
+            get_proposal_instruction_address_seeds, InstructionData, ProposalInstructionV2,
         },
         token_owner_record::get_token_owner_record_data_for_proposal_owner,
     },
-    tools::account::create_and_serialize_account_signed,
 };
 
 /// Processes InsertInstruction instruction
 pub fn process_insert_instruction(
     program_id: &Pubkey,
     accounts: &[AccountInfo],
+    option_index: u16,
     instruction_index: u16,
     hold_up_time: u32,
     instruction: InstructionData,
@@ -70,24 +70,24 @@ pub fn process_insert_instruction(
 
     token_owner_record_data.assert_token_owner_or_delegate_is_signer(governance_authority_info)?;
 
-    match instruction_index.cmp(&proposal_data.instructions_next_index) {
+    let option = &mut proposal_data.options[option_index as usize];
+
+    match instruction_index.cmp(&option.instructions_next_index) {
         Ordering::Greater => return Err(GovernanceError::InvalidInstructionIndex.into()),
         // If the index is the same as instructions_next_index then we are adding a new instruction
         // If the index is below instructions_next_index then we are inserting into an existing empty space
         Ordering::Equal => {
-            proposal_data.instructions_next_index = proposal_data
-                .instructions_next_index
-                .checked_add(1)
-                .unwrap();
+            option.instructions_next_index = option.instructions_next_index.checked_add(1).unwrap();
         }
         Ordering::Less => {}
     }
 
-    proposal_data.instructions_count = proposal_data.instructions_count.checked_add(1).unwrap();
+    option.instructions_count = option.instructions_count.checked_add(1).unwrap();
     proposal_data.serialize(&mut *proposal_info.data.borrow_mut())?;
 
-    let proposal_instruction_data = ProposalInstruction {
-        account_type: GovernanceAccountType::ProposalInstruction,
+    let proposal_instruction_data = ProposalInstructionV2 {
+        account_type: GovernanceAccountType::ProposalInstructionV2,
+        option_index,
         instruction_index,
         hold_up_time,
         instruction,
@@ -96,12 +96,13 @@ pub fn process_insert_instruction(
         proposal: *proposal_info.key,
     };
 
-    create_and_serialize_account_signed::<ProposalInstruction>(
+    create_and_serialize_account_signed::<ProposalInstructionV2>(
         payer_info,
         proposal_instruction_info,
         &proposal_instruction_data,
         &get_proposal_instruction_address_seeds(
             proposal_info.key,
+            &option_index.to_le_bytes(),
             &instruction_index.to_le_bytes(),
         ),
         program_id,
