@@ -2,19 +2,19 @@
 
 use solana_program::{
     account_info::{next_account_info, AccountInfo},
+    clock::Clock,
     entrypoint::ProgramResult,
     pubkey::Pubkey,
+    sysvar::Sysvar,
 };
+use spl_governance_tools::account::dispose_account;
 
-use crate::{
-    state::{
-        enums::{ProposalState, VoteWeight},
-        governance::get_governance_data,
-        proposal::get_proposal_data_for_governance_and_governing_mint,
-        token_owner_record::get_token_owner_record_data_for_realm_and_governing_mint,
-        vote_record::get_vote_record_data_for_proposal_and_token_owner,
-    },
-    tools::account::dispose_account,
+use crate::state::{
+    enums::ProposalState,
+    governance::get_governance_data,
+    proposal::get_proposal_data_for_governance_and_governing_mint,
+    token_owner_record::get_token_owner_record_data_for_realm_and_governing_mint,
+    vote_record::{get_vote_record_data_for_proposal_and_token_owner, Vote},
 };
 
 use borsh::BorshSerialize;
@@ -54,8 +54,14 @@ pub fn process_relinquish_vote(program_id: &Pubkey, accounts: &[AccountInfo]) ->
     )?;
     vote_record_data.assert_can_relinquish_vote()?;
 
-    // If the Proposal is still being voted on then the token owner vote won't count towards the outcome
-    if proposal_data.state == ProposalState::Voting {
+    let clock = Clock::get()?;
+
+    // If the Proposal is still being voted on then the token owner vote will be withdrawn and it won't count towards the vote outcome
+    // Note: If there is no tipping point the proposal can be still in Voting state but already past the configured max_voting_time
+    //       It means it awaits manual finalization (FinalizeVote) and it should no longer be possible to withdraw the vote and we only release the tokens
+    if proposal_data.state == ProposalState::Voting
+        && !proposal_data.has_vote_time_ended(&governance_data.config, clock.unix_timestamp)
+    {
         let governance_authority_info = next_account_info(account_info_iter)?; // 5
         let beneficiary_info = next_account_info(account_info_iter)?; // 6
 
@@ -64,20 +70,26 @@ pub fn process_relinquish_vote(program_id: &Pubkey, accounts: &[AccountInfo]) ->
         token_owner_record_data
             .assert_token_owner_or_delegate_is_signer(governance_authority_info)?;
 
-        match vote_record_data.vote_weight {
-            VoteWeight::Yes(vote_amount) => {
-                proposal_data.yes_votes_count = proposal_data
-                    .yes_votes_count
-                    .checked_sub(vote_amount)
-                    .unwrap();
+        match vote_record_data.vote {
+            Vote::Approve(choices) => {
+                for (option, choice) in proposal_data.options.iter_mut().zip(choices) {
+                    option.vote_weight = option
+                        .vote_weight
+                        .checked_sub(choice.get_choice_weight(vote_record_data.voter_weight)?)
+                        .unwrap();
+                }
             }
-            VoteWeight::No(vote_amount) => {
-                proposal_data.no_votes_count = proposal_data
-                    .no_votes_count
-                    .checked_sub(vote_amount)
-                    .unwrap();
+            Vote::Deny => {
+                proposal_data.deny_vote_weight = Some(
+                    proposal_data
+                        .deny_vote_weight
+                        .unwrap()
+                        .checked_sub(vote_record_data.voter_weight)
+                        .unwrap(),
+                )
             }
-        };
+        }
+
         proposal_data.serialize(&mut *proposal_info.data.borrow_mut())?;
 
         dispose_account(vote_record_info, beneficiary_info);
