@@ -2,9 +2,11 @@
 
 pub mod enums;
 pub mod governance;
+pub mod legacy;
 pub mod proposal;
 pub mod proposal_instruction;
 pub mod realm;
+pub mod realm_config;
 pub mod signatory_record;
 pub mod token_owner_record;
 pub mod vote_record;
