@@ -18,7 +18,8 @@ async fn test_deposit_initial_community_tokens() {
     // Act
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     // Assert
 
@@ -61,7 +62,8 @@ async fn test_deposit_initial_council_tokens() {
     // Act
     let token_owner_record_cookie = governance_test
         .with_council_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     // Assert
     let token_owner_record = governance_test
@@ -100,7 +102,8 @@ async fn test_deposit_subsequent_community_tokens() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let deposit_amount = 5;
     let total_deposit_amount = token_owner_record_cookie
@@ -146,7 +149,8 @@ async fn test_deposit_subsequent_council_tokens() {
 
     let token_owner_record_cookie = governance_test
         .with_council_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let deposit_amount = 5;
     let total_deposit_amount = token_owner_record_cookie
@@ -192,12 +196,15 @@ async fn test_deposit_initial_community_tokens_with_owner_must_sign_error() {
     let transfer_authority = Keypair::new();
     let token_source = Keypair::new();
 
+    let amount = 10;
+
     governance_test
+        .bench
         .create_token_account_with_transfer_authority(
             &token_source,
             &realm_cookie.account.community_mint,
             &realm_cookie.community_mint_authority,
-            10,
+            amount,
             &token_owner,
             &transfer_authority.pubkey(),
         )
@@ -209,15 +216,17 @@ async fn test_deposit_initial_community_tokens_with_owner_must_sign_error() {
         &token_source.pubkey(),
         &token_owner.pubkey(),
         &transfer_authority.pubkey(),
-        &governance_test.context.payer.pubkey(),
+        &governance_test.bench.context.payer.pubkey(),
+        amount,
         &realm_cookie.account.community_mint,
     );
 
     instruction.accounts[3] = AccountMeta::new_readonly(token_owner.pubkey(), false);
 
-    // // Act
+    // Act
 
     let error = governance_test
+        .bench
         .process_transaction(&[instruction], Some(&[&transfer_authority]))
         .await
         .err()
@@ -238,12 +247,15 @@ async fn test_deposit_initial_community_tokens_with_invalid_owner_error() {
 
     let invalid_owner = Keypair::new();
 
+    let amount = 10;
+
     governance_test
+        .bench
         .create_token_account_with_transfer_authority(
             &token_source,
             &realm_cookie.account.community_mint,
             &realm_cookie.community_mint_authority,
-            10,
+            amount,
             &token_owner,
             &transfer_authority.pubkey(),
         )
@@ -255,13 +267,15 @@ async fn test_deposit_initial_community_tokens_with_invalid_owner_error() {
         &token_source.pubkey(),
         &invalid_owner.pubkey(),
         &transfer_authority.pubkey(),
-        &governance_test.context.payer.pubkey(),
+        &governance_test.bench.context.payer.pubkey(),
+        amount,
         &realm_cookie.account.community_mint,
     );
 
     // // Act
 
     let error = governance_test
+        .bench
         .process_transaction(&[instruction], Some(&[&transfer_authority, &invalid_owner]))
         .await
         .err()
@@ -279,14 +293,18 @@ async fn test_deposit_community_tokens_with_malicious_holding_account_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
+
+    let amount = 50;
 
     governance_test
+        .bench
         .mint_tokens(
             &realm_cookie.account.community_mint,
             &realm_cookie.community_mint_authority,
             &token_owner_record_cookie.token_source,
-            50,
+            amount,
         )
         .await;
 
@@ -296,7 +314,8 @@ async fn test_deposit_community_tokens_with_malicious_holding_account_error() {
         &token_owner_record_cookie.token_source,
         &token_owner_record_cookie.token_owner.pubkey(),
         &token_owner_record_cookie.token_owner.pubkey(),
-        &governance_test.context.payer.pubkey(),
+        &governance_test.bench.context.payer.pubkey(),
+        amount,
         &realm_cookie.account.community_mint,
     );
 
@@ -306,6 +325,7 @@ async fn test_deposit_community_tokens_with_malicious_holding_account_error() {
     // Act
 
     let err = governance_test
+        .bench
         .process_transaction(
             &[deposit_ix],
             Some(&[&token_owner_record_cookie.token_owner]),
