@@ -3,9 +3,9 @@ use solana_sdk::signature::Keypair;
 use spl_governance::{
     addins::voter_weight::VoterWeightRecord,
     state::{
-        governance::Governance, proposal::Proposal, proposal_instruction::ProposalInstruction,
+        governance::Governance, proposal::ProposalV2, proposal_instruction::ProposalInstructionV2,
         realm::Realm, realm_config::RealmConfigAccount, signatory_record::SignatoryRecord,
-        token_owner_record::TokenOwnerRecord, vote_record::VoteRecord,
+        token_owner_record::TokenOwnerRecord, vote_record::VoteRecordV2,
     },
 };
 
@@ -134,7 +134,7 @@ pub struct GovernanceCookie {
 #[derive(Debug)]
 pub struct ProposalCookie {
     pub address: Pubkey,
-    pub account: Proposal,
+    pub account: ProposalV2,
 
     pub proposal_owner: Pubkey,
 }
@@ -149,13 +149,13 @@ pub struct SignatoryRecordCookie {
 #[derive(Debug)]
 pub struct VoteRecordCookie {
     pub address: Pubkey,
-    pub account: VoteRecord,
+    pub account: VoteRecordV2,
 }
 
 #[derive(Debug)]
 pub struct ProposalInstructionCookie {
     pub address: Pubkey,
-    pub account: ProposalInstruction,
+    pub account: ProposalInstructionV2,
     pub instruction: Instruction,
 }
 
